# Changelog

<!--next-version-placeholder-->

## v1.1.0 (2022-10-08)
### Documentation
* Fix spellings in readme ([`7a764a5`](https://github.com/Stephen-RA-King/pynnacle/commit/7a764a5b1214d55dadb0ecbf763933691031a68d))
* Fix markdown link ([`b9d8c93`](https://github.com/Stephen-RA-King/pynnacle/commit/b9d8c93f77ea9934ee37162eda612a85867acece))

## v1.0.2 (2022-08-01)
### Fix
* Add badges ([`8c2f5ce`](https://github.com/Stephen-RA-King/pynnacle/commit/8c2f5ce52855e9e3d41c3eadb2c18488f4322dc9))
* Update readthedocs yml file ([`a1429d9`](https://github.com/Stephen-RA-King/pynnacle/commit/a1429d9d00ba0bbea0c9862fcfcf21c2ab108659))

## v1.0.1 (2022-05-31)
### Fix
* Update URI to png ([`e810a79`](https://github.com/Stephen-RA-King/pynnacle/commit/e810a7956b265abcb7ebf1cafce76554ee63309e))
* Refresh project support files ([`ee21182`](https://github.com/Stephen-RA-King/pynnacle/commit/ee21182bdb771b4a45dd64d4e2088bf28eca89cd))

## 0.1.0 (2022-05-31)

### First Release of 'pynnacle'



<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pynnacle)
